@@ -1,6 +1,6 @@
 from uuid import uuid1
 
-from ..query.annotations import SpeakerGraphQuery
+from ..query.annotations import SplitQuery
 from ..query.base.func import Max, Min
 from ..exceptions import GraphQueryError
 from ..io.importer import utterance_data_to_csvs, import_utterance_csv, create_utterance_csvs, \
@@ -9,12 +9,15 @@ from .pause import PauseContext
 
 
 class UtteranceContext(PauseContext):
+    """
+    Class that contains methods for dealing specifically with utterances
+    """
     def reset_utterances(self):
         """
         Remove all utterance annotations.
         """
         try:
-            q = SpeakerGraphQuery(self, self.utterance)
+            q = SplitQuery(self, self.utterance)
             q.delete()
             self.hierarchy.remove_annotation_type('utterance')
             self.encode_hierarchy()
@@ -64,17 +67,22 @@ class UtteranceContext(PauseContext):
             utt_data = self.get_utterance_ids(d, min_pause_length, min_utterance_length)
             speaker_data = {}
             for s, utterances in utt_data.items():
-                speaker_data[s] = []
+                speaker_data = []
                 prev_id = None
                 for u in utterances:
                     cur_id = uuid1()
                     row = {'id': cur_id, 'prev_id': prev_id,
                            'begin_word_id': u[0],
                            'end_word_id': u[1]}
-                    speaker_data[s].append(row)
+                    speaker_data.append(row)
                     prev_id = cur_id
-            utterance_data_to_csvs(self, speaker_data)
+                utterance_data_to_csvs(self, s, d, speaker_data)
         import_utterance_csv(self, call_back, stop_check)
+        for m in self.hierarchy.acoustics:
+            self.reassess_utterances(m)
+            if m == 'pitch':
+                self.hierarchy.add_token_properties(self, 'utterance', [('pitch_last_edited', int)])
+                self.encode_hierarchy()
         if stop_check is not None and stop_check():
             return
         if call_back is not None:
