@@ -1,14 +1,14 @@
 
 from .helper import guess_textgrid_format
 
-from .parsers import (BuckeyeParser, CsvParser, IlgParser, OrthographyTextParser,
+from .parsers import (BuckeyeParser, IlgParser, OrthographyTextParser,
                     TranscriptionTextParser, TextgridParser, TimitParser,
-                    MfaParser, LabbCatParser, FaveParser, PartiturParser)
+                    MfaParser, MausParser, LabbCatParser, FaveParser, PartiturParser)
 
-from .inspect import (inspect_buckeye, inspect_csv, inspect_orthography,
+from .inspect import (inspect_buckeye, inspect_orthography,
                     inspect_transcription, inspect_textgrid, inspect_timit,
                     inspect_ilg, inspect_mfa, inspect_labbcat,
-                    inspect_fave, inspect_partitur)
+                    inspect_fave, inspect_partitur, inspect_maus)
 
 from .exporters import save_results
 
